@@ -6,6 +6,7 @@ use regex::Regex;
 use std::fs;
 use std::path::PathBuf;
 use std::process::{Command, Stdio};
+mod x11_ffi;
 
 pub struct NetBSDBatteryReadout;
 
@@ -170,8 +171,8 @@ impl GeneralReadout for NetBSDGeneralReadout {
                 let width = unsafe { XDisplayWidth(display, screen) };
                 let height = unsafe { XDisplayHeight(display, screen) };
 
-                unsafe { XCloseDisplay(display) };
                 unsafe {
+                    XCloseDisplay(display);
                     libc::free(display_name as *mut libc::c_void);
                 }
 
